/*
 * Created on 01.11.2005
 */
package de.unikassel.ir.test;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

import junit.framework.TestCase;
import de.unikassel.ir.vsr.Corpus;
import de.unikassel.ir.vsr.CorpusImpl;
import de.unikassel.ir.vsr.Document;
import de.unikassel.ir.vsr.DocumentImpl;

/**
 * TestFall für einfache Boolesche Anfragen auf einem
 * {@link de.unikassel.ir.vsr.Corpus}.
 * 
 * @author Christoph Schmitz
 */
public class BooleanTest extends TestCase {
	private Corpus _corpus;

	public void setUp() throws FileNotFoundException, IOException {
		_corpus = new CorpusImpl();

		File dir = new File("texte");
		for (File file : dir.listFiles()) {
			if (!file.isDirectory()) {
				FileInputStream stream = new FileInputStream(file);
				Document doc = new DocumentImpl(file.getName());
				doc.read(stream);
				stream.close();
				_corpus.addDocument(doc);
			}
		}
	}

	public void testAndQuery() {
		// folgende Anfrage sollte die Dokumente 1, 5258, 8961 und 13462
		// liefern.
		Set<String> expectedIDs = new HashSet<String>();
		for (String id : new String[] { "1", "5258", "8961", "13462" }) {
			expectedIDs.add("Reut_" + id + ".txt");
		}

		Set<String> resultIDs = new HashSet<String>();
		Collection<Document> docs = _corpus.getDocumentsContainingAll("cocoa",
				"shipment");
		for (Document doc : docs) {
			resultIDs.add(doc.getId());
		}
		assertEquals(expectedIDs, resultIDs);
	}

	public void testOrQuery() {
		Set<String> expectedIDs = new HashSet<String>();

		// folgende Anfrage sollte die Dokumente 49, 2310, 5258, 6657, 12179,
		// 12772, 12924, 13462 liefern.
		for (String id : new String[] { "49", "2310", "5258", "6657", "12179",
				"12772", "12924", "13462" }) {
			expectedIDs.add("Reut_" + id + ".txt");
		}

		Set<String> resultIDs = new HashSet<String>();
		Collection<Document> docs = _corpus.getDocumentsContainingAny(
				"alternative", "daily");
		for (Document doc : docs) {
			resultIDs.add(doc.getId());
		}
		assertEquals(expectedIDs, resultIDs);

	}
}
